@@ -210,7 +210,7 @@ def interceptor(rn_environ, *args, **kwargs):
 
         if getattr(callback, 'status_code', None):
             status_code = callback.status_code
-            errors = [callback.reason_phrase, callback.__class__.__name__]
+            errors = [callback.__class__.__name__, callback.reason_phrase]
             interceptor_error(status_code, errors, ctx=ctx)
 
         if conf.profile_http_header_enabled:
